@@ -32,6 +32,7 @@ NULL
 #' @name as.speeches
 #' @exportMethod as.speeches
 #' @rdname as.speeches
+#' @importFrom cli cli_progress_step cli_progress_done
 #' @examples 
 #' use("polmineR")
 #' speeches <- as.speeches(
@@ -80,16 +81,18 @@ setMethod("as.speeches", "partition", function(
     )
     if (isFALSE(speaker_is_descendent)){
       stop(
-        "s-attribute 's_attribute_name' is not a sibling of 's_attribute_date' ",
-        "but is not a descendent then as would be expected"
+        "s-attribute 's_attribute_name' is not a sibling of 's_attribute_date'",
+        " but is not a descendent then as would be expected"
       )
     }
     xml <- "nested"
   }
   
   # as a first step, create partitions by date
-  .message("generating partitions by date", verbose = verbose)
-  if (length(s_attributes(.Object, s_attribute_date)) > 1L){
+  n_dates <- length(s_attributes(.Object, s_attribute_date))
+  if (verbose) cli_alert_info("distinct dates detected: {.val {n_dates}}")
+  if (n_dates > 1L){
+    if (verbose) cli_progress_step("subsetting by date")
     # The subcorpus may have been generated by a subset on s_attribute date,
     # using a regular expression - which will result in ugly names. Remove it.
     while(s_attribute_date %in% names(.Object@s_attributes))
@@ -99,6 +102,7 @@ setMethod("as.speeches", "partition", function(
       .Object,
       s_attribute = s_attribute_date
     )
+    if (verbose) cli_progress_done()
   } else {
     # if .Object originates from a subcorpus object, the s-attributes slot
     # is potentially not filled. Populate it to get proper obj names
@@ -109,7 +113,7 @@ setMethod("as.speeches", "partition", function(
     partition_bundle_dates <- list(.Object)
   }
   
-  .message("generating speeches", verbose = verbose)
+  if (verbose) cli_progress_step("generating speeches")
   .split_by_speakers <- function(partition_date, ...){
     nested <- lapply(
       s_attributes(partition_date, s_attribute_name),
@@ -131,7 +135,7 @@ setMethod("as.speeches", "partition", function(
     mc = mc, progress = progress
   )
   speaker_list <- do.call(c, unlist(speaker_list_nested, recursive = FALSE))
-  .message("generating names", verbose = verbose)
+  if (verbose) cli_progress_step("generating names")
   partition_names <- sapply(
     speaker_list,
     function(x){
@@ -152,7 +156,7 @@ setMethod("as.speeches", "partition", function(
     for (i in rev(empty_partitions)) speaker_list[[i]] <- NULL
 
   # the resulting list may be totally unordered - reorder now
-  .message("reordering partitions", verbose = verbose)
+  if (progress) cli_progress_step("reordering partitions")
   speaker_list_ordered <- lapply(
     order(sapply(speaker_list, function(x) x@cpos[1,1])),
     function(i) speaker_list[[i]]
@@ -165,11 +169,12 @@ setMethod("as.speeches", "partition", function(
   if ("type" %in% properties){
     type <- corpus_property(.Object@corpus, .Object@registry_dir, "type")
     if (type == "plpr"){
-      .message("coercing partitions to plpr_partitions", verbose = verbose)
+      if (verbose) cli_progress_step("coercing partitions to plpr_partitions")
       speaker_list_ordered <- lapply(
         speaker_list_ordered,
         function(x) as(x, "plpr_partition")
       )
+      if (verbose) cli_progress_done()
     }
   }
   
@@ -177,6 +182,8 @@ setMethod("as.speeches", "partition", function(
 })
 
 
+#' @importFrom cli cli_progress_bar cli_progress_update
+#' @importFrom RcppCWB s_attr_relationship
 #' @exportMethod as.speeches
 #' @rdname as.speeches
 setMethod("as.speeches", "subcorpus", function(
@@ -185,15 +192,94 @@ setMethod("as.speeches", "subcorpus", function(
   s_attribute_name = grep("name", s_attributes(.Object), value = TRUE),
   gap = 500, mc = FALSE, verbose = TRUE, progress = TRUE
 ){
-  as.speeches(
-    .Object = as(.Object, "partition"),
-    s_attribute_date = s_attribute_date,
-    s_attribute_name = s_attribute_name,
-    gap = gap,
-    mc = mc, verbose = verbose, progress = progress
+  stopifnot(
+    is.character(s_attribute_date),
+    length(s_attribute_date) == 1L,
+    
+    is.character(s_attribute_name),
+    length(s_attribute_name) == 1L
   )
-}
-)
+  
+  relation <- s_attr_relationship(
+    x = s_attribute_date,
+    y = s_attribute_name,
+    corpus = .Object@corpus,
+    registry = .Object@registry_dir
+  )
+  
+  xml <- if (relation == 0L) "flat" else "nested"
+
+  # as a first step, create subcorpora by date
+  n_dates <- length(s_attributes(.Object, s_attribute_date))
+  if (verbose) cli_alert_info("distinct dates: {.val {n_dates}}")
+  if (n_dates > 1L){
+    if (verbose) cli_progress_step("subsetting by date")
+    # The subcorpus may have been generated by a subset on s_attribute date,
+    # using a regular expression - which will result in ugly names. Remove it.
+    while(s_attribute_date %in% names(.Object@s_attributes))
+      .Object@s_attributes[[s_attribute_date]] <- NULL
+    
+    sc_by_date <- split(.Object, s_attribute = s_attribute_date)
+    if (verbose) cli_progress_done()
+  } else {
+    sc_by_date <- list(.Object)
+  }
+  
+  if (verbose) cli_alert_info("generating speeches")
+  .fn <- function(by_date)
+    lapply(
+      split(by_date, s_attribute = s_attribute_name, verbose = FALSE)@objects,
+      function(by_name) split(
+        as(by_name, "partition"), gap = gap, verbose = TRUE
+      )@objects
+    )
+
+  nested <- if (progress) pblapply(sc_by_date, .fn) else lapply(sc_by_date, .fn)
+  speaker_list <- do.call(c, unlist(nested, recursive = FALSE))
+  
+  if (verbose) cli_progress_step("generating names")
+  obj_names <- sapply(
+    speaker_list,
+    function(x){
+      name <- s_attributes(x, s_attribute = s_attribute_name)
+      date <- s_attributes(x, s_attribute = s_attribute_date)
+      paste(
+        name, date, gsub("^.*_(\\d+)$", "\\1", x@name),
+        sep = "_", collapse = "_"
+      )
+    }
+  )
+  for (i in 1L:length(speaker_list)) name(speaker_list[[i]]) <- obj_names[i]
+  
+  # at this stage, the list may contain partitions of size 0 - discard
+  empty <- which(sapply(speaker_list, size) == 0L)
+  if (length(empty) > 0L) for (i in rev(empty)) speaker_list[[i]] <- NULL
+  
+  # the resulting list may be totally unordered - reorder now
+  if (progress) cli_progress_step("reorder objects")
+  speaker_list_ordered <- lapply(
+    order(sapply(speaker_list, function(x) x@cpos[1,1])),
+    function(i) speaker_list[[i]]
+  )
+  corpus <- if (is.character(.Object)) .Object else .Object@corpus
+  properties <- corpus_properties(
+    corpus = .Object@corpus,
+    registry = .Object@registry_dir
+  )
+  if ("type" %in% properties){
+    type <- corpus_property(.Object@corpus, .Object@registry_dir, "type")
+    if (type == "plpr"){
+      if (verbose) cli_progress_step("coercing partitions to plpr_subcorpus")
+      speaker_list_ordered <- lapply(
+        speaker_list_ordered,
+        function(x) as(as(x, "subcorpus"), "plpr_subcorpus")
+      )
+      if (verbose) cli_progress_done()
+    }
+  }
+  
+  as.bundle(speaker_list_ordered)
+})
 
 
 #' @param subset A `logical` expression evaluated in a temporary `data.table`
