@@ -62,16 +62,16 @@ setMethod("corpus", "character", function(
 
     c_regdir <- path(corpus_registry_dir(.Object))
     if (missing(registry_dir)){
-      if (is.na(c_regdir)){
-        stop(
-          "Cannot initialize corpus object - ",
-          "cannot derive argument 'registry' from C representation of corpus."
-        )
-      } else if (length(c_regdir) > 1L){
+      if (length(c_regdir) > 1L){
         stop(
           "Cannot initialize corpus object - ",
           "corpus defined by two different registry files."
         )
+      } else if (is.na(c_regdir)){
+        stop(
+          "Cannot initialize corpus object - ",
+          "cannot derive argument 'registry' from C representation of corpus."
+        )
       } else {
         registry_dir <- c_regdir
       }
@@ -117,6 +117,8 @@ setMethod("corpus", "character", function(
       name = corpus_full_name(corpus = .Object, registry = registry_dir)
     )
     
+    y@xml <- if (is_nested(y)) "nested" else "flat"
+    
     return(y)
   } else {
     if (missing(restricted)) restricted <- FALSE
@@ -144,12 +146,12 @@ setMethod("get_corpus", "textstat", function(x) x@corpus)
 
 #' @exportMethod get_corpus
 #' @rdname corpus_methods
-#' @details Use \code{get_corpus}-method to get the corpus ID from the slot
-#'   \code{corpus} of the \code{corpus} object.
+#' @details Use `get_corpus()`-method to get the corpus ID from the slot
+#'   `corpus` of the `corpus` object.
 setMethod("get_corpus", "corpus", function(x) x@corpus)
 
 #' @exportMethod get_corpus
-#' @describeIn subcorpus Get the corpus ID from the \code{subcorpus} object.
+#' @describeIn subcorpus Get the corpus ID from the `subcorpus` object.
 setMethod("get_corpus", "subcorpus", function(x) x@corpus)
 
 
@@ -285,7 +287,7 @@ setMethod("corpus", "missing", function(){
 #'   keep. The expression may be unevaluated (using \code{quote} or
 #'   \code{bquote}).
 #' @importFrom data.table setindexv setDT
-#' @importFrom rlang enquo eval_tidy
+#' @importFrom rlang enquo eval_tidy is_quosure
 #' @param regex A \code{logical} value. If \code{TRUE}, values for s-attributes
 #'   defined using the three dots (...) are interpreted as regular expressions
 #'   and passed into a \code{grep} call for subsetting a table with the regions
@@ -307,7 +309,14 @@ setMethod("subset", "corpus", function(x, subset, regex = FALSE, ...){
       eval_tidy(expr),
       error = function(e) FALSE
     )
-    if (is.call(evaluated)) expr <- eval_tidy(expr)
+    if (is.call(evaluated)){
+      is_call <- TRUE
+      expr <- eval_tidy(expr)
+    } else if (is_quosure(expr)){
+      is_call <- if (is.call(quo_get_expr(expr))) TRUE else FALSE
+    } else {
+      is_call <- FALSE
+    }
 
     s_attr_expr <- s_attributes(expr, corpus = x) # get s_attributes present in the expression
     s_attr <- c(s_attr, s_attr_expr)
@@ -350,8 +359,9 @@ setMethod("subset", "corpus", function(x, subset, regex = FALSE, ...){
     cpos_right = rng[seq.int(from = 2L, to = length(rng), by = 2L)]
   )
 
-  # Now we add the values of the s-attributes to the data.table with regions, one at
-  # a time. Again, doing this from the binary files directly is faster than using RcppCWB.
+  # Now we add the values of the s-attributes to the data.table with regions,
+  # one at a time. Again, doing this from the binary files directly is faster
+  # than using RcppCWB.
   for (i in seq_along(s_attr)){
     if (!s_attr[i] %in% s_attributes(x)){
       warning(sprintf("structural attribute '%s' not defined", s_attr[i]))
@@ -361,28 +371,44 @@ setMethod("subset", "corpus", function(x, subset, regex = FALSE, ...){
       avs = fs::path(x@data_dir, paste(s_attr[i], "avs", sep = ".")),
       avx = fs::path(x@data_dir, paste(s_attr[i], "avx", sep = "."))
     )
-    sizes <- lapply(files, function(file) file.info(file)[["size"]])
-
-    avx <- readBin(files[["avx"]], what = integer(), size = 4L, n = sizes[["avx"]] / 4L, endian = "big")
-    avx_matrix <- matrix(avx, ncol = 2, byrow = TRUE)
-
-    avs <- readBin(con = files[["avs"]], what = character(), n = sizes[["avs"]])
-    if (!is.null(encoding)) Encoding(avs) <- x@encoding
-
-    dt[, (s_attr[i]) := avs[match(avx_matrix[, 2], unique(avx_matrix[, 2]))] ]
+    if (all(file.exists(unlist(files)))){
+      sizes <- lapply(files, function(file) file.info(file)[["size"]])
+      
+      avx <- readBin(
+        files[["avx"]],
+        what = integer(),
+        size = 4L,
+        n = sizes[["avx"]] / 4L,
+        endian = "big"
+      )
+      avx_matrix <- matrix(avx, ncol = 2, byrow = TRUE)
+      
+      avs <- readBin(
+        con = files[["avs"]],
+        what = character(),
+        n = sizes[["avs"]]
+      )
+      if (!is.null(encoding)) Encoding(avs) <- x@encoding
+      
+      dt[, (s_attr[i]) := avs[match(avx_matrix[, 2], unique(avx_matrix[, 2]))] ]
+    } else {
+      cli_alert_info("s_attribute {.val {s_attr[i]}} does not have values")
+    }
   }
-
+  
   # Apply the expression.
   if (!missing(subset)){
-    # Adjust the encoding of the expression to the one of the corpus. Adjusting
-    # encodings is expensive, so the (small) epression will be adjusted to the
-    # encoding of the corpus, not vice versa
-    
-    if (encoding(expr) != x@encoding) encoding(expr) <- x@encoding
-    
-    setindexv(dt, cols = s_attr)
-    success <- try({dt <- dt[eval_tidy(expr, data = dt)]})
-    if (is(success, "try-error")) return(NULL)
+    if (is_call){
+      # Adjust the encoding of the expression to the one of the corpus. Adjusting
+      # encodings is expensive, so the (small) epression will be adjusted to the
+      # encoding of the corpus, not vice versa
+      
+      if (encoding(expr) != x@encoding) encoding(expr) <- x@encoding
+      
+      setindexv(dt, cols = s_attr)
+      success <- try({dt <- dt[eval_tidy(expr, data = dt)]})
+      if (is(success, "try-error")) return(NULL)
+    }
   }
 
   if (length(dots) > 0L){
@@ -418,7 +444,7 @@ setMethod("subset", "corpus", function(x, subset, regex = FALSE, ...){
   y@strucs = dt[["struc"]]
   y@s_attribute_strucs <- s_attr[length(s_attr)]
   y@s_attributes <- lapply(setNames(s_attr, s_attr), function(s) unique(dt[[s]]))
-  y@xml <- "flat"
+  y@xml <- x@xml
   y@name <- ""
   y@size <- size(y)
   
@@ -440,12 +466,18 @@ setMethod("subset", "subcorpus", function(x, subset, ...){
     eval_tidy(expr),
     error = function(e) FALSE
   )
-  if (is.call(evaluated)) expr <- eval_tidy(expr)
-  
-  if (encoding(expr) != x@encoding) encoding(expr) <- x@encoding
+  if (is.call(evaluated)){
+    expr <- eval_tidy(expr)
+    if (encoding(expr) != x@encoding) encoding(expr) <- x@encoding
+  }
 
-  s_attr <- s_attributes(expr, corpus = x) # get s_attributes present in the expression
-  dt <- data.table(struc = x@strucs, cpos_left = x@cpos[,1], cpos_right = x@cpos[,2])
+  # get s_attributes present in the expression
+  s_attr <- s_attributes(expr, corpus = x) 
+  dt <- data.table(
+    struc = x@strucs,
+    cpos_left = x@cpos[, 1],
+    cpos_right = x@cpos[, 2]
+  )
   
   s_attr_sizes <- sapply(
     unique(c(x@s_attribute_strucs, s_attr)),
@@ -516,24 +548,29 @@ setMethod("subset", "subcorpus", function(x, subset, ...){
       # Slower by necessity
       strucs <- cl_cpos2struc(
         x@corpus, registry = x@registry_dir,
-        s_attribute = s_attr[1], cpos = cpos(x@cpos)
+        s_attribute = s_attr[1], cpos = ranges_to_cpos(x@cpos)
       )
-      strucs <- unique(strucs[strucs >= 0])
+      strucs <- unique(strucs[strucs >= 0L])
       ranges <- get_region_matrix(
         x@corpus, registry = x@registry_dir,
         s_attribute = s_attr[1], strucs = strucs
       )
-      str <- cl_struc2str(
-        corpus = x@corpus, registry = x@registry_dir,
-        s_attribute = s_attr[1], struc = strucs
-      )
-      Encoding(str) <- x@encoding
       dt <- data.table(
         struc = strucs,
         cpos_left = ranges[,1],
         cpos_right = ranges[,2]
       )
-      dt[, (s_attr[1]) := str]
+      
+      # this is a somewhat dirty assumption that s_attr will not have values
+      if (is.call(quo_get_expr(expr))){
+        str <- cl_struc2str(
+          corpus = x@corpus, registry = x@registry_dir,
+          s_attribute = s_attr[1], struc = strucs
+        )
+        Encoding(str) <- x@encoding
+        dt[, (s_attr[1]) := str]
+      }
+      
       if (length(s_attr) > 1L){
         for (s in s_attr[-1]){
           str <- cl_struc2str(
@@ -558,29 +595,25 @@ setMethod("subset", "subcorpus", function(x, subset, ...){
     
   }
   
-  setindexv(dt, cols = s_attr)
+  x@s_attribute_strucs = s_attr[length(s_attr)]
   
-  success <- try({dt_min <- dt[eval_tidy(expr, data = dt)]})
-  if (is(success, "try-error")) return(NULL)
-  
-  y <- new(
-    "subcorpus",
-    corpus = x@corpus,
-    registry_dir = x@registry_dir,
-    template = x@template,
-    info_file = x@info_file,
-    encoding = x@encoding,
-    type = x@type,
-    data_dir = x@data_dir,
-    cpos = as.matrix(dt_min[, c("cpos_left", "cpos_right")]),
-    strucs = dt_min[["struc"]],
-    s_attributes = c(x@s_attributes, lapply(setNames(s_attr, s_attr), function(s) unique(dt_min[[s]]))),
-    s_attribute_strucs = s_attr[length(s_attr)],
-    xml = "flat",
-    name = x@name
-  )
-  y@size <- size(y)
-  y
+  if (is.call(quo_get_expr(expr))){
+    setindexv(dt, cols = s_attr)
+    success <- try({dt_min <- dt[eval_tidy(expr, data = dt)]})
+    if (is(success, "try-error")) return(NULL)
+    x@cpos <- as.matrix(dt_min[, c("cpos_left", "cpos_right")])
+    x@strucs <- dt_min[["struc"]]
+    x@s_attributes <- c(
+      x@s_attributes,
+      lapply(setNames(s_attr, s_attr), function(s) unique(dt_min[[s]]))
+    )
+  } else {
+    x@cpos <- as.matrix(dt[, c("cpos_left", "cpos_right")])
+    x@strucs <- dt[["struc"]]
+  }
+
+  x@size <- size(x)
+  x
 })
 
 
@@ -612,26 +645,39 @@ setMethod("show", "corpus", function(object){
 #' # get corpus ID
 #' corpus("REUTERS") %>% get_corpus()
 #'
-#' # use $ to access s_attributes quickly
+#' # use $ to access corpus properties
 #' use("polmineR")
 #' g <- corpus("GERMAPARLMINI")
 #' g$date
-#' corpus("GERMAPARLMINI")$date #
-#' corpus("GERMAPARLMINI") %>% s_attributes(s_attribute = "date") # equivalent
-#'
-#' use("polmineR")
-#' sc <- subset("GERMAPARLMINI", date == "2009-10-27")
-#' sc$date
+#' corpus("GERMAPARLMINI")$build_date #
+#' gparl <- corpus("GERMAPARLMINI")
+#' gparl$version %>%
+#'   as.numeric_version()
+#' 
 #' @exportMethod $
 #' @rdname corpus_methods
-#' @param x An object of class \code{corpus}, or inheriting from it.
+#' @param x An object of class `corpus`, or inheriting from it.
 #' @param name A (single) s-attribute.
-setMethod("$", "corpus", function(x, name) s_attributes(x, s_attribute = name))
+#' @importFrom RcppCWB corpus_properties corpus_property
+setMethod("$", "corpus", function(x, name){
+  
+  properties <- corpus_properties(corpus = x@corpus, registry = x@registry_dir)
+  if (!name %in% properties){
+    warning(sprintf("property `%s` is not defined, returning NA", name))
+    return(NA_character_)
+  }
+    
+  corpus_property(
+    corpus = x@corpus,
+    registry = x@registry_dir,
+    property = name
+  )
+})
 
 #' @param object An object of class \code{subcorpus_bundle}.
 #' @rdname subcorpus_bundle
 setMethod("show", "subcorpus_bundle", function (object) {
-  message('** subcorpus_bundle object: **')
+  message('<<subcorpus_bundle>>')
   message(sprintf('%-25s', 'Number of subcorpora:'), length(object@objects))
 })
 
