@@ -1,6 +1,18 @@
 #' @include count.R S4classes.R
 NULL
 
+#' @importFrom stringi stri_sub
+.character_ngrams <- function(x, n, char){
+  if (char[1] != ""){
+    splitted <- unlist(strsplit(x, ""))
+    splitted <- ifelse(splitted %in% char, splitted, NA)
+    x <- paste(splitted[which(!is.na(splitted))], sep = "", collapse = "")
+  }
+  ngrams <- stringi::stri_sub(x, from = 1L:(nchar(x) - n + 1L), to = n:nchar(x))
+  dt <- data.table(ngram = ngrams)[, .N, by = "ngram"]
+  setnames(dt, old = "N", new = "count")
+  dt
+}
 
 #' Get N-Grams
 #' 
@@ -41,18 +53,18 @@ setMethod("ngrams", "partition", function(.Object, ...) callNextMethod(.Object,
 setMethod("ngrams", "character", function(.Object, ...) callNextMethod(.Object, ...))
 
 #' @rdname ngrams
-setMethod("ngrams", "partition", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, ...){
-  ngrams(.Object = as(.Object, "subcorpus"), n = n, p_attribute = p_attribute, char = char, progress = progress, ...)
+setMethod("ngrams", "partition", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, mc = 1L, ...){
+  ngrams(.Object = as(.Object, "subcorpus"), n = n, p_attribute = p_attribute, char = char, progress = progress, mc = mc, ...)
 })
 
 #' @rdname ngrams
-setMethod("ngrams", "subcorpus", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, ...){
+setMethod("ngrams", "subcorpus", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, mc = 1L, ...){
   callNextMethod()
 })
 
 #' @rdname ngrams
-setMethod("ngrams", "character", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, ...){
-  ngrams(.Object = corpus(.Object), n = n, p_attribute = p_attribute, char = char, progress = progress, ...)
+setMethod("ngrams", "character", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, mc = 1L, ...){
+  ngrams(.Object = corpus(.Object), n = n, p_attribute = p_attribute, char = char, progress = progress, mc = mc, ...)
 })
 
 
@@ -91,7 +103,7 @@ setMethod("ngrams", "data.table", function(.Object, n = 2L, p_attribute = "word"
 
 #' @rdname ngrams
 #' @importFrom pbapply pbsapply
-setMethod("ngrams", "corpus", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, ...){
+setMethod("ngrams", "corpus", function(.Object, n = 2, p_attribute = "word", char = NULL, progress = FALSE, mc = 1L, ...){
   
   if ("pAttribute" %in% names(list(...))) p_attribute <- list(...)[["pAttribute"]]
   
@@ -140,23 +152,7 @@ setMethod("ngrams", "corpus", function(.Object, n = 2, p_attribute = "word", cha
     setcolorder(TF, neworder = c(colnames(TF)[!colnames(TF) %in% "count"], "count"))
   } else {
     char_soup_base <- get_token_stream(.Object, p_attribute = p_attribute[1], collapse = "")
-    char_soup <- unlist(strsplit(char_soup_base, ""))
-    if (char[1] != ""){
-      char_soup <- unname(unlist(sapply(char_soup, function(x) ifelse(x %in% char, x, NA))))
-      if (any(is.na(char_soup))) char_soup[-which(is.na(char_soup))]
-    }
-    char_soup <- paste(char_soup[which(!is.na(char_soup))], sep = "", collapse = "")
-    char_soup_total <- nchar(char_soup)
-    
-    .fn <- function(x) substr(char_soup, x, x + n - 1L)
-    iter_values <- 1L:(char_soup_total - n + 1L)
-    ngrams <- if (isTRUE(progress)) pbsapply(iter_values, .fn) else sapply(iter_values, .fn)
-
-    tabled_ngrams <- table(ngrams)
-    TF <- data.table(
-      ngram = names(tabled_ngrams),
-      count = unname(as.vector(tabled_ngrams))
-      )
+    TF <- .character_ngrams(x = char_soup_base, n = n, char = char)
   }
   
   y <- as(as(.Object, "corpus"), "ngrams")
@@ -173,12 +169,47 @@ setMethod("ngrams", "partition_bundle", function(.Object, n = 2, char = NULL, p_
   
   if ("pAttribute" %in% names(list(...))) p_attribute <- list(...)[["pAttribute"]]
   
-  retval <- new("bundle")
-  retval@objects <- blapply(
-    .Object@objects, f = ngrams,
-    n = n, p_attribute = p_attribute, char = char, mc = mc, progress = progress
+  retval <- as(as(.Object, "corpus"), "bundle")
+  
+  if (is.null(char)){
+    retval@objects <- blapply(
+      .Object@objects, f = ngrams,
+      n = n, p_attribute = p_attribute, char = char, mc = mc, progress = progress
     )
-  retval@p_attribute <- unique(unlist(lapply(retval@objects, function(x) x@p_attribute)))
+    retval@p_attribute <- unique(unlist(lapply(retval@objects, function(x) x@p_attribute)))
+  } else {
+    retval@p_attribute <- p_attribute
+    li <- get_token_stream(.Object, p_attribute = p_attribute[1], collapse = "", verbose = FALSE)
+    if (progress){
+      if (mc){
+        dts <- pblapply(li, .character_ngrams, n = n, char = char, cl = mc)
+      } else {
+        dts <- pblapply(li, .character_ngrams, n = n, char = char, cl = NULL)
+      }
+    } else {
+      if (mc){
+        dts <- mclapply(li, .character_ngrams, n = n, char = char, mc.cores = mc)
+      } else {
+        dts <- lapply(li, .character_ngrams, n = n, char = char)
+      }
+    }
+    
+    proto <- as(as(.Object, "corpus"), "ngrams")
+    proto@n = as.integer(n)
+    proto@p_attribute = if (is.null(char)) p_attribute else "ngram"
+    
+    retval@objects <- lapply(
+      1L:length(dts),
+      function(i){
+        proto@stat <- dts[[i]]
+        proto@size <- as.integer(size(.Object[[i]]))
+        proto@name <- names(.Object)[[i]]
+        proto
+      }
+    )
+  }
+  
   names(retval@objects) <- names(.Object)
+  
   retval
 })
\ No newline at end of file
