@@ -20,12 +20,14 @@
 #' @importFrom stringi stri_match_all_regex
 #' @importFrom RcppCWB cqp_reset_registry cqp_get_registry cqp_initialize
 #' @seealso To conveniently reset registry, see \code{\link{use}}.
+#' @keywords internal
 #' @examples
 #' \dontrun{
 #' x <- system.file(package = "polmineR", "extdata", "cwb", "registry")
 #' registry_reset(registryDir = x)
 #' }
 registry_reset <- function(registryDir = registry(), verbose = TRUE) {
+  lifecycle::deprecate_warn("0.8.7", "registry_reset()")
   
   if (!file.exists(registryDir)) stop("registry directory does not exist")
   oldRegistry <- Sys.getenv("CORPUS_REGISTRY")
@@ -69,19 +71,28 @@ registry_reset <- function(registryDir = registry(), verbose = TRUE) {
 #' @importFrom stringi stri_match_all_regex
 #' @export registry_get_name
 #' @rdname registry_eval
+#' @keywords internal
 registry_get_name = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")){
+  lifecycle::deprecate_warn(
+    "0.8.7",
+    "registry_get_name()",
+    "RcppCWB::corpus_full_name()"
+  )
   .registry_eval(corpus = corpus, registry = registry, regex = "^NAME\\s+(.*?)\\s*$")
 }
 
 #' @export registry_get_id
 #' @rdname registry_eval
+#' @keywords internal
 registry_get_id = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")){
+  lifecycle::deprecate_warn("0.8.7", "registry_get_id()")
   .registry_eval(corpus = corpus, registry = registry, regex = "^ID\\s+(.*?)\\s*$")
 }
 
 
 #' @export registry_get_home
 #' @rdname registry_eval
+#' @keywords internal
 registry_get_home = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")) {
   lifecycle::deprecate_warn(
     "0.8.6",
@@ -94,7 +105,13 @@ registry_get_home = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")) {
 
 #' @export registry_get_info
 #' @rdname registry_eval
+#' @keywords internal
 registry_get_info = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")) {
+  lifecycle::deprecate_warn(
+    "0.8.7",
+    "registry_get_info()",
+    "RcppCWB::corpus_info_file()"
+  )
   y <- .registry_eval(corpus = corpus, registry = registry, regex = '^INFO\\s+"?(.*?)"?\\s*$')
   normalizePath(path = y, winslash = "/", mustWork = FALSE)
 }
@@ -110,8 +127,7 @@ registry_get_info = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")) {
 #' @export registry_get_encoding
 #' @rdname registry_eval
 #' @importFrom lifecycle deprecate_warn
-#' @examples
-#' registry_get_encoding("REUTERS")
+#' @keywords internal
 registry_get_encoding = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")) {
   lifecycle::deprecate_warn(
     "0.8.6",
@@ -130,21 +146,41 @@ registry_get_encoding = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY"
 
 #' @export registry_get_p_attributes
 #' @rdname registry_eval
+#' @keywords internal
 registry_get_p_attributes = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")) {
+  lifecycle::deprecate_warn(
+    "0.8.7",
+    "registry_get_p_attributes()",
+    "RcppCWB::corpus_p_attributes()"
+  )
+  
   .registry_eval(corpus = corpus, registry = registry, regex = "^ATTRIBUTE\\s+(.*?)$")
 }
 
 
 #' @export registry_get_s_attributes
 #' @rdname registry_eval
+#' @keywords internal
 registry_get_s_attributes = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")) {
+  lifecycle::deprecate_warn(
+    "0.8.7",
+    "registry_get_s_attributes()",
+    "RcppCWB::corpus_s_attributes()"
+  )
   .registry_eval(corpus = corpus, registry = registry, regex = "^STRUCTURE\\s+(.*?)(|\\s+.*?)$")
 }
 
 
 #' @export registry_get_properties
 #' @rdname registry_eval
+#' @keywords internal
 registry_get_properties = function(corpus, registry = Sys.getenv("CORPUS_REGISTRY")) {
+  lifecycle::deprecate_warn(
+    "0.8.7",
+    "registry_get_properties()",
+    "RcppCWB::corpus_properties()"
+  )
+  
   registry_file <- path(registry, tolower(corpus))
   if (isFALSE(file.exists(registry_file))){
     stop("There is no registry file for corpus ", corpus, ".")
@@ -232,18 +268,14 @@ registry_move <- function(corpus, registry, registry_new, home_dir_new){
 #' @importFrom stringi stri_enc_mark
 registry <- function(pkg = NULL){
   if (is.null(pkg)){
-    if (tolower(Sys.getenv("POLMINER_USE_TMP_REGISTRY")) != "false"){
-      y <- path(tempdir(), "polmineR_registry")
-      
-      # The user name may include special characters. On windows, a possible solutions to avoid
-      # error messages, is to use the DOS short path name.
-      if (stri_enc_mark(y) != "ASCII"){
-        if (.Platform$OS.type == "windows") y <- utils::shortPathName(y)
-      }
-      return(y)
-    } else {
-      return(Sys.getenv("CORPUS_REGISTRY"))
+    y <- path(tempdir(), "polmineR_registry")
+    
+    # The user name may include special characters. On windows, a possible solutions to avoid
+    # error messages, is to use the DOS short path name.
+    if (stri_enc_mark(y) != "ASCII"){
+      if (.Platform$OS.type == "windows") y <- utils::shortPathName(y)
     }
+    return(y)
   } else {
     stopifnot(
       is.character(pkg),
