@@ -9,11 +9,17 @@ NULL
 #' `partition_bundle` objects.
 #' 
 #' @param .Object The object to be trimmed
-#' @param termsToKeep ...
-#' @param termsToDrop ...
-#' @param docsToKeep ...
-#' @param docsToDrop ...
-#' @param verbose logical
+#' @param terms_to_drop A `character` vector with terms to exclude from matrix
+#'   (terms used as stopwords).
+#' @param docs_to_keep A `character` vector with documents to keep.
+#' @param min_count A `numeric` value with a minimum value of total term
+#'   frequency across documents to exclude rare terms from matrix.
+#' @param min_doc_length A `numeric` value with minimum total of the summed-up
+#'  occurrence of tokens in a document. Exclude documents below this value and
+#'  filter out short documents. Note that the `min_doc_length` filter is applied
+#'  before filtering for `min_count` and `terms_to_keep`, and that these filters
+#'  will reduce document lengths.
+#' @param verbose A `logical` value, whether to output progress messages.
 #' @param ... further arguments
 #' @author Andreas Blaette
 #' @docType methods
@@ -28,34 +34,108 @@ setGeneric("trim", function(.Object, ...) standardGeneric("trim") )
 #' @importFrom tm stopwords
 #' @importFrom slam as.simple_triplet_matrix
 #' @rdname trim-method
-setMethod("trim", "TermDocumentMatrix", function(.Object, termsToKeep = NULL, termsToDrop = NULL, docsToKeep = NULL, docsToDrop = NULL, verbose = TRUE){
-  .rmBlank <- function(mat, verbose=TRUE){
-    .message("removing empty rows", verbose = verbose)
-    matTmp <- as.sparseMatrix(mat)
-    matTmp <- matTmp[which(rowSums(matTmp) > 0),]
-    mat <- as.simple_triplet_matrix(matTmp)
-    class(mat) <- c("TermDocumentMatrix", "simple_triplet_matrix")
-    mat
-  }
-  if (!is.null(docsToKeep)){
-    .Object <- .Object[,which(colnames(.Object) %in% docsToKeep)]
-  }
-  if (!is.null(docsToDrop)){
-    .Object <- .Object[,which(!colnames(.Object) %in% docsToDrop)]
-  }
-  if (!is.null(termsToKeep)){
-    .Object <- .Object[which(rownames(.Object) %in% termsToKeep),]
-  }
-  if (!is.null(termsToDrop)){
-    .Object <- .Object[which(!rownames(.Object) %in% termsToDrop), ]
-  }
-  .Object
+#' @importFrom lifecycle deprecate_warn
+#' @examples
+#' use("RcppCWB", corpus = "REUTERS")
+#' dtm <- corpus("REUTERS") %>%
+#'   split(s_attribute = "id") %>%
+#'   as.DocumentTermMatrix(p_attribute = "word", verbose = FALSE)
+#' trim(dtm, min_doc_length = 100)
+setMethod("trim", "TermDocumentMatrix", function(.Object, terms_to_drop, docs_to_keep, min_count, min_doc_length, verbose = TRUE, ...){
+  t(trim(
+    t(.Object),
+    terms_to_drop = terms_to_drop,
+    docs_to_keep = docs_to_keep,
+    min_count = min_count,
+    min_doc_length = min_doc_length
+  ))
 })
 
 
 #' @rdname trim-method
-setMethod("trim", "DocumentTermMatrix", function(.Object, ...){
-  t(trim(t(.Object), ...))
+#' @importFrom slam row_sums
+#' @importFrom cli cli_alert_info
+#' @importFrom slam col_sums
+setMethod("trim", "DocumentTermMatrix", function(.Object, terms_to_drop, docs_to_keep, min_count, min_doc_length, verbose = TRUE, ...){
+  if ("termsToKeep" %in% names(list(...)))
+    deprecate_warn("0.8.8", "DocumentTermMatrix(termsToKeep)")
+  
+  if ("termsToDrop" %in% names(list(...))){
+    deprecate_warn(
+      "0.8.8",
+      what = "DocumentTermMatrix(termsToDrop)",
+      with = "DocumentTermMatrix(terms_to_drop)"
+    )
+  }
+
+  if ("docsToKeep" %in% names(list(...))){
+    deprecate_warn(
+      "0.8.8",
+      what = "DocumentTermMatrix(docsToKeep)",
+      with = "DocumentTermMatrix(docs_to_keep)"
+    )
+  }
+    
+  if ("docsToDrop" %in% names(list(...))){
+    deprecate_warn("0.8.8", "DocumentTermMatrix(docsToDrop)")
+  }
+  
+  purge <- FALSE # set to TRUE on demand
+  
+  if (!missing(docs_to_keep)){
+    nrow_old <- nrow(.Object)
+    rows_to_keep <- which(rownames(.Object) %in% docs_to_keep)
+    .Object <- .Object[rows_to_keep,]
+    if (verbose) cli_alert_info(
+      "apply docs_to_keep - dropped {.val {nrow_old - nrow(.Object)}} docs"
+    )
+  }
+  
+  if (!missing(min_doc_length)){
+    nrow_old <- nrow(.Object)
+    stopifnot(is.numeric(min_doc_length))
+    docs_to_drop <- which(row_sums(.Object) < min_doc_length)
+    if (length(docs_to_drop) > 0L) .Object <- .Object[-docs_to_drop,]
+    if (verbose) cli_alert_info(
+      "minimum document length {.val {min_doc_length}} - dropped {.val {nrow_old - nrow(.Object)}} docs (keeping {.val {nrow(.Object)}})"
+    )
+  }
+   
+  if (!missing(terms_to_drop)){
+    ncol_old <- ncol(.Object)
+    stopifnot(is.character(terms_to_drop))
+    cols_to_drop <- which(colnames(.Object) %in% unique(terms_to_drop))
+    if (length(cols_to_drop) > 0L) .Object <- .Object[,-cols_to_drop]
+    if (verbose) cli_alert_info(
+      "exclude terms_to_drop - dropped {.val {ncol_old - ncol(.Object)}} terms (keeping {.val {ncol(.Object)}})"
+    )
+    purge <- TRUE # cleanup empty docs later
+  }
+
+  if (!missing(min_count)){
+    stopifnot(is.numeric(min_count))
+    ncol_old <- ncol(.Object)
+    rare_terms <- which(col_sums(.Object) < min_count)
+    if (length(rare_terms) > 0L){
+      .Object <- .Object[,-rare_terms]
+      purge <- TRUE
+    }
+    if (verbose) cli_alert_info(
+      "exclude infrequent terms - dropped {.val {ncol_old - ncol(.Object)}} terms (keeping {.val {ncol(.Object)}})"
+    )
+  }
+  
+  if (purge){
+    empty_docs <- which(row_sums(.Object) == 0L)
+    if (length(empty_docs) > 0L){
+      .Object <- .Object[-empty_docs,]
+      if (verbose) cli_alert_info(
+        "dropped {.val {length(empty_docs)}} docs with no tokens left"
+      )
+    }
+  }
+
+  .Object
 })
 
 
@@ -101,7 +181,7 @@ setMethod("trim", "context", function(.Object, s_attribute = NULL, positivelist
     .message("filtering by positivelist", verbose = verbose)
     before <- length(unique(.Object@cpos[["match_id"]]))
     if (is.matrix(positivelist)){
-      dt <- data.table(cpos = cpos(positivelist), positivelist = TRUE)
+      dt <- data.table(cpos = ranges_to_cpos(positivelist), positivelist = TRUE)
       cpos_min <- dt[.Object@cpos[.Object@cpos[["position"]] != 0], on = "cpos"]
       matches_to_keep <- cpos_min[,
         if (any(!is.na(.SD$positivelist))) .SD else NULL,
