@@ -1,5 +1,7 @@
 library(polmineR)
+
 use("polmineR")
+use(pkg = "RcppCWB", corpus = "REUTERS")
 
 testthat::context("p_attributes")
 
@@ -23,7 +25,7 @@ test_that(
     )
     expect_identical(
       length(p_attributes(corpus("REUTERS"), p_attribute = "word")),
-      RcppCWB::cl_lexicon_size("REUTERS", p_attribute = "word")
+      RcppCWB::cl_lexicon_size("REUTERS", p_attribute = "word", registry = registry())
     )
   }
 )
